@@ -1,17 +1,31 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * bsd-cdrom.c: BSD CD controlling functions.
+ *  Authors: Iain Holmes <iain@ximian.com>
+ *           Theo van Klaveren  <t.vanklaveren@student.utwente.nl>
+ *
+ *  Copyright 2001 Iain Holmes
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- * Copyright (C) 2001 Iain Holmes
- * Authors: Iain Holmes  <iain@ximian.com>
- *          Theo van Klaveren  <t.vanklaveren@student.utwente.nl>
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 #include <sys/types.h>
 #include <sys/ioctl.h>
 #include <fcntl.h>
@@ -166,7 +180,7 @@ bsd_cdrom_update_cd (GnomeCDRom *cdrom)
 {
 	BSDCDRom *lcd = BSD_CDROM (cdrom);
 	BSDCDRomPrivate *priv;
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
 	struct ioc_read_toc_single_entry tocentry;
 #else
 	struct ioc_read_toc_entry tocentries;
@@ -195,7 +209,7 @@ bsd_cdrom_update_cd (GnomeCDRom *cdrom)
 
 	bsd_cdrom_invalidate (lcd);
 	priv->track_info = g_malloc ((priv->number_tracks + 1) * sizeof (BSDCDRomTrackInfo));
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
 	for (i = 0, j = priv->track0; i < priv->number_tracks; i++, j++) {
 		tocentry.track = j;
 		tocentry.address_format = CD_MSF_FORMAT;
@@ -207,7 +221,7 @@ bsd_cdrom_update_cd (GnomeCDRom *cdrom)
 		tocentries.address_format = CD_MSF_FORMAT;
 #endif
 
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
 		if (ioctl (cdrom->fd, CDIOREADTOCENTRY, &tocentry) < 0) {
 #else
 		if (ioctl (cdrom->fd, CDIOREADTOCENTRYS, &tocentries) < 0) {
@@ -217,7 +231,7 @@ bsd_cdrom_update_cd (GnomeCDRom *cdrom)
 		}
 
 		priv->track_info[i].track = j;
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
 		priv->track_info[i].audio_track = tocentry.entry.control == 0 ? 1 : 0;
 		ASSIGN_MSF (priv->track_info[i].address, tocentry.entry.addr.msf);
 #else
@@ -226,7 +240,7 @@ bsd_cdrom_update_cd (GnomeCDRom *cdrom)
 #endif
 	}
 
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
 	/* On BSD, the leadout track is the track LAST_TRACK + 1. */
 	tocentry.track = priv->number_tracks + 1;
 	tocentry.address_format = CD_MSF_FORMAT;
@@ -241,7 +255,7 @@ bsd_cdrom_update_cd (GnomeCDRom *cdrom)
 		bsd_cdrom_invalidate (lcd);
 		return;
 	}
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
 	ASSIGN_MSF (priv->track_info[priv->number_tracks].address, tocentry.entry.addr.msf);
 #else
 	ASSIGN_MSF (priv->track_info[priv->number_tracks].address, tocentry.addr.msf);
@@ -265,7 +279,7 @@ bsd_cdrom_eject (GnomeCDRom *cdrom,
 		return FALSE;
 	}
 
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
 	if (gnome_cdrom_get_status (cdrom, &status, error) == FALSE) {
 		bsd_cdrom_close (lcd);
 		g_free (status);
@@ -902,7 +916,7 @@ bsd_cdrom_get_status (GnomeCDRom *cdrom,
 		return FALSE;
 	}
 #endif
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
 	/* FIXME: Figure out how to do this on BSD */
 #else
 	if (ioctl (cdrom->fd, CDIOREADTOCHEADER, priv->tochdr) < 0) {
